import React, { useState, useEffect } from 'react';
import {
  DatePicker,
  Table,
  Row,
  Col,
  Button,
  notification,
  message,
  Spin,
} from 'antd';
import { SwapRightOutlined } from '@ant-design/icons';
import { Chart, Interval, Tooltip, Axis } from 'bizcharts';
import { DataSet } from '@antv/data-set';
import moment from 'moment';
import { post, PUBLISH_SERVICE } from '@/services/index';

// const data = [
//   { value: 251, name: '接口名称一', subName: '子事例一' },
//   { value: 1041, name: '接口名称三', subName: '子事例二' },
//   { value: 610, name: '接口名称二', subName: '子事例二' },
//   { value: 434, name: '接口名称二', subName: '子事例四' },
//   { value: 335, name: '接口名称二', subName: '子事例五' },
//   { value: 250, name: '接口名称三', subName: '子事例二' },
// ];
// const data = [];

const Demo = () => {
  const [loading, setLoading] = useState(false); // 源数据
  const [data0, setData0] = useState([]); // 源数据
  const [pathCount, setPathCount] = useState([]); // 接口调用次数,统计数据
  const [reponseTime, setReponseTime] = useState([]); // 接口调用时长,统计数据
  const [scale, setScale] = useState({}); // 坐标轴别名
  const [startTime, setStartTime] = useState(moment().startOf('day')); // 默认值当天0点
  const [endTime, setEndTime] = useState(
    moment(new Date(), 'YYYY-MM-DD HH:mm:ss'), // 默认值当前时间
  );
  const [tableColumns, setTableColumns] = useState([]); // 源数据

  console.log(startTime.format('HH:mm:ss'));
  console.log(endTime.format('HH:mm:ss'));

  // 在起止时间任意一个变化后获取数据
  useEffect(() => {
    if (startTime && endTime) {
      setLoading(true);
      getData();
    }
  }, [startTime, endTime]);
  const getData = () => {
    post(`${PUBLISH_SERVICE}/LogCenter/GetOMSLog`, {
      PageIndex: 0,
      PageSize: 0,
      DateFrom: startTime.format('YYYY-MM-DD'),
      DateTo: endTime.format('YYYY-MM-DD'),
      HourFrom: startTime.format('HH:mm:ss'),
      HourTo: endTime.format('HH:mm:ss'),
      IP: '',
      Module: '',
      LogType: 0,
      Description: '',
      LoginName: '',
      UserName: '',
    })
      .then(res => {
        if (res.code === 0) {
          setData0(res.data);
          dataTransforrm(res.data);
          console.log(res.data);
        } else {
          notification.error({
            message: '数据获取失败',
            description: res.message,
          });
        }
        setLoading(false);
      })
      .catch(err => {
        message.error(err);
        setLoading(false);
      });
  };
  const dataTransforrm = data => {
    data.map((item, index) => {
      item.key = index;
      return item;
    });
    const columns = Object.keys(data[0]).map(key => ({
      title: key,
      dataIndex: key,
      key,
    }));
    setTableColumns(columns);
    // console.log(Object.keys(data[0]));
    const scale1 = {
      Path: {
        alias: '接口名称', // 别名
      },
      响应时长: {
        alias: '响应时长/ms', // 别名
      },
    };
    setScale(scale1);

    const dv1 = new DataSet.View().source(data);
    dv1
      .transform({
        type: 'aggregate', // 别名summary
        fields: ['Path'], // 统计字段集
        operations: ['count'], // 统计操作集
        as: ['计数'], // 存储字段集
        groupBy: ['Path'], // 分组字段集
      })
      .transform({
        type: 'sort-by',
        fields: ['计数'], // 根据指定的字段集进行排序，与lodash的sortBy行为一致
        order: 'DESC', // 默认为 ASC，DESC 则为逆序
      });
    console.log(dv1.rows);
    setPathCount(dv1.rows.slice(0, 20));

    const dv2 = new DataSet.View().source(data);
    dv2
      .transform({
        type: 'aggregate', // 别名summary
        fields: ['ConsumerTime'], // 统计字段集
        operations: ['mean'], // 统计操作集
        as: ['响应时长'], // 存储字段集
        groupBy: ['Path'], // 分组字段集
      })
      .transform({
        type: 'sort-by',
        fields: ['响应时长'], // 根据指定的字段集进行排序，与lodash的sortBy行为一致
        order: 'DESC', // 默认为 ASC，DESC 则为逆序
      });
    console.log(dv2.rows);
    setReponseTime(dv2.rows.slice(0, 20));
  };

  // DatePicker改变点击确定时
  const changeStartTime = time => {
    setStartTime(time);
  };
  const changeEndTime = time => {
    setEndTime(time);
  };
  // 近1/6/12/24小时
  const setTime = time => {
    setEndTime(moment(new Date(), 'YYYY-MM-DD HH:mm:ss'));
    setStartTime(
      moment(
        new Date(new Date().getTime() - time * 60 * 60 * 1000),
        'YYYY-MM-DD HH:mm:ss',
      ),
    );
  };

  return (
    <>
      <Row>
        <div style={{ lineHeight: 2 }}>时间：</div>
        <DatePicker
          showTime
          format="YYYY-MM-DD HH:mm:ss"
          placeholder="起始时间"
          value={startTime}
          onChange={changeStartTime}
          allowClear={false}
        />
        <SwapRightOutlined style={{ lineHeight: 2 }} />
        <DatePicker
          showTime
          format="YYYY-MM-DD HH:mm:ss"
          placeholder="结束时间"
          value={endTime}
          onChange={changeEndTime}
          style={{ marginRight: '10px' }}
          allowClear={false}
        />
        <Col span={12}>
          <Button onClick={() => setTime(1)}>近1小时</Button>
          <Button onClick={() => setTime(6)}>近6小时</Button>
          <Button onClick={() => setTime(12)}>近12小时</Button>
          <Button onClick={() => setTime(24)}>近1天</Button>
          <Button onClick={() => setTime(24 * 7)}>近1周</Button>
        </Col>
        {/* <div style={{ lineHeight: 2 }}>类型：</div> */}
      </Row>
      <Spin spinning={loading} tip="loading">
        <Row style={{ padding: '10px' }}>
          <Col span={12}>
            <Chart
              height={340}
              width={400}
              autoFit
              data={pathCount}
              interactions={['active-region']}
              padding="auto"
              scale={scale}
            >
              <Axis
                name="Path"
                label="null"
                title={{ offset: 20, position: 'end' }}
              />
              <Axis name="计数" title />
              <Interval position="Path*计数" />
              <Tooltip shared />
            </Chart>
          </Col>
          <Col span={12}>
            <Chart
              height={340}
              width={400}
              autoFit
              data={reponseTime}
              interactions={['active-region']}
              padding="auto"
              scale={scale}
            >
              <Axis
                name="Path"
                label="null"
                title={{ offset: 20, position: 'end' }}
              />
              <Axis name="响应时长" title />
              <Interval position="Path*响应时长" />
              <Tooltip shared />
            </Chart>
          </Col>
        </Row>
        <Table
          size="small"
          bordered
          columns={tableColumns || []}
          dataSource={data0}
          // loading={tableLoading}
          scroll={{ x: 'max-content' }}
          pagination={{
            showTotal: (total, range) =>
              `第${range[0]}-${range[1]} 条/共 ${total} 条`,
            pageSizeOptions: [10, 20, 50, 100],
            defaultPageSize: 10,
            showQuickJumper: true,
            showSizeChanger: true,
          }}
        />
      </Spin>
    </>
  );
};
export default Demo;
// dv.transform({
//   type: 'aggregate', // 别名summary
//   fields: ['name', 'value'], // 统计字段集
//   operations: ['count', 'mean'], // 统计操作集
//   as: ['计数', '平均值'], // 存储字段集
//   groupBy: ['name'], // 分组字段集
// }).transform({
//   type: 'sort-by',
//   fields: ['计数'], // 根据指定的字段集进行排序，与lodash的sortBy行为一致
//   order: 'DESC', // 默认为 ASC，DESC 则为逆序
// });
// const data = [
//   {
//     ID: '215341',
//     loginName: 'gcwqgps',
//     userName: 'gcwqgps',
//     systemType: 'solution',
//     terminal: 'Browser',
//     IP: '192.168.10.150',
//     logTime: '2020/11/23 18:56:27',
//   },
//   {
//     ID: '215342',
//     loginName: 'luojian',
//     userName: 'gwcj',
//     systemType: 'city',
//     terminal: 'Browser',
//     IP: '127.0.0.1',
//     logTime: '2020/11/23 19:17:51',
//   },
//   {
//     ID: '215343',
//     loginName: 'luojian',
//     userName: 'gwcj',
//     systemType: 'city',
//     terminal: 'Browser',
//     IP: '127.0.0.1',
//     logTime: '2020/11/23 19:41:12',
//   },
//   {
//     ID: '215344',
//     loginName: 'luojian',
//     userName: 'gwcj',
//     systemType: 'city',
//     terminal: 'Browser',
//     IP: '127.0.0.1',
//     logTime: '2020/11/23 19:42:04',
//   },
//   {
//     ID: '215345',
//     loginName: 'luojian',
//     userName: 'gwcj',
//     systemType: 'city',
//     terminal: 'Browser',
//     IP: '127.0.0.1',
//     logTime: '2020/11/23 19:45:56',
//   },
//   {
//     ID: '215346',
//     loginName: 'panda',
//     userName: '熊猫智慧水务',
//     systemType: 'city',
//     terminal: 'Browser',
//     IP: '192.168.10.150',
//     logTime: '2020/11/23 19:55:20',
//   },
//   {
//     ID: '215347',
//     loginName: 'luojian',
//     userName: 'gwcj',
//     systemType: 'city',
//     terminal: 'Browser',
//     IP: '127.0.0.1',
//     logTime: '2020/11/23 19:55:39',
//   },
//   {
//     ID: '215348',
//     loginName: '17671748304',
//     userName: '邹小仙',
//     systemType: 'city',
//     terminal: 'Browser',
//     IP: '192.168.10.150',
//     logTime: '2020/11/23 20:01:34',
//   },
//   {
//     ID: '215349',
//     loginName: 'luojian',
//     userName: 'gwcj',
//     systemType: 'city',
//     terminal: 'Browser',
//     IP: '127.0.0.1',
//     logTime: '2020/11/23 20:16:51',
//   },
// ];
